# Ubuntu CI Engine
# Copyright 2014 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import subprocess
import unittest


class TestStatic(unittest.TestCase):

    def test_no_bare_exit(self):
        output = subprocess.check_output(
            ['bzr', 'grep', '--from-root', '-n', '(^| )exit\('])
        self.assertEqual('', output,
                         msg='''\
The 'exit' method should not be used outside the interactive
interpreter.
https://docs.python.org/2/library/constants.html#exit
Please use sys.exit() below:
''' + output)

    def test_python_shebang(self):
        output = subprocess.check_output(
            ['bzr', 'grep', '--from-root', '-n', '^#!/.*/python'])
        msg = ('''
Do not call /usr/bin/python directly in a shebang (#!) as this breaks
virtualenv. Instead, use '#!/usr/bin/env python' in the instances below:
''' + output)
        self.assertEqual('', output, msg=msg)
