# Rather than opt-in to PEP8 and pyflakes testing module-by-module, these tests
# cover all python code, non-module code included, with an explicit opt-out.

import os
import pep8
import cStringIO
from pyflakes import api, reporter
import unittest


HERE = os.path.abspath(os.path.dirname(__file__))
ROOT = os.path.abspath(os.path.join(HERE, '..'))
EXCLUDE = [
    # Migrations are automatically generated.
    'migrations',
    # TODO ev 2014-11-15 cupstream2distro is an understood mess.
    'cupstream2distro',
    # An arguably reasonable use of star imports.
    'ticket_system/ticket/tests/__init__.py',
]


class TestSyntax(unittest.TestCase):
    def test_pep8(self):
        guide = pep8.StyleGuide(paths=[ROOT], exclude=EXCLUDE)
        report = guide.check_files()
        errors = report.total_errors
        self.assertEqual(errors, 0, '{} PEP8 errors.'.format(errors))

    def test_pyflakes(self):
        (out, err) = (cStringIO.StringIO(), cStringIO.StringIO())
        report = reporter.Reporter(out, err)
        errors = 0
        for dirpath, dirnames, filenames in os.walk(ROOT):
            for filename in filenames:
                path = os.path.join(dirpath, filename)
                excluded = any(excl in path for excl in EXCLUDE)
                if filename.endswith('.py') and not excluded:
                    errors += api.checkPath(path, report)
        error_text = out.getvalue()
        msg = '\n{}\n\n{} pyflakes errors.'
        self.assertEqual(errors, 0, msg.format(error_text, errors))
